psutil: Cross-platform lib for process and system monitoring in Python.
=======================================================================

Description
-----------

Cross-platform lib for process and system monitoring in Python.

License
-------

BSD-3-Clause

Upstream Contact
----------------

https://pypi.org/project/psutil/

